@@ -30,20 +30,22 @@ const (
 )
 
 type Instance struct {
-	Name         string             `json:"name"`
-	Status       Status             `json:"status"`
-	Dir          string             `json:"dir"`
-	Arch         limayaml.Arch      `json:"arch"`
-	CPUType      string             `json:"cpuType"`
-	CPUs         int                `json:"cpus,omitempty"`
-	Memory       int64              `json:"memory,omitempty"` // bytes
-	Disk         int64              `json:"disk,omitempty"`   // bytes
-	Message      string             `json:"message,omitempty"`
-	Networks     []limayaml.Network `json:"network,omitempty"`
-	SSHLocalPort int                `json:"sshLocalPort,omitempty"`
-	HostAgentPID int                `json:"hostAgentPID,omitempty"`
-	QemuPID      int                `json:"qemuPID,omitempty"`
-	Errors       []error            `json:"errors,omitempty"`
+	Name            string             `json:"name"`
+	Status          Status             `json:"status"`
+	Dir             string             `json:"dir"`
+	VMType          limayaml.VMType    `json:"vmType"`
+	Arch            limayaml.Arch      `json:"arch"`
+	CPUType         string             `json:"cpuType"`
+	CPUs            int                `json:"cpus,omitempty"`
+	Memory          int64              `json:"memory,omitempty"` // bytes
+	Disk            int64              `json:"disk,omitempty"`   // bytes
+	Message         string             `json:"message,omitempty"`
+	AdditionalDisks []limayaml.Disk    `json:"additionalDisks,omitempty"`
+	Networks        []limayaml.Network `json:"network,omitempty"`
+	SSHLocalPort    int                `json:"sshLocalPort,omitempty"`
+	HostAgentPID    int                `json:"hostAgentPID,omitempty"`
+	DriverPID       int                `json:"driverPID,omitempty"`
+	Errors          []error            `json:"errors,omitempty"`
 }
 
 func (inst *Instance) LoadYAML() (*limayaml.LimaYAML, error) {
@@ -78,6 +80,7 @@ func Inspect(instName string) (*Instance, error) {
 		return inst, nil
 	}
 	inst.Arch = *y.Arch
+	inst.VMType = *y.VMType
 	inst.CPUType = y.CPUType[*y.Arch]
 
 	inst.CPUs = *y.CPUs
@@ -89,6 +92,7 @@ func Inspect(instName string) (*Instance, error) {
 	if err == nil {
 		inst.Disk = disk
 	}
+	inst.AdditionalDisks = y.AdditionalDisks
 	inst.Networks = y.Networks
 	inst.SSHLocalPort = *y.SSH.LocalPort // maybe 0
 
@@ -117,22 +121,22 @@ func Inspect(instName string) (*Instance, error) {
 		}
 	}
 
-	inst.QemuPID, err = ReadPIDFile(filepath.Join(instDir, filenames.QemuPID))
+	inst.DriverPID, err = ReadPIDFile(filepath.Join(instDir, filenames.PIDFile(*y.VMType)))
 	if err != nil {
 		inst.Status = StatusBroken
 		inst.Errors = append(inst.Errors, err)
 	}
 
 	if inst.Status == StatusUnknown {
-		if inst.HostAgentPID > 0 && inst.QemuPID > 0 {
+		if inst.HostAgentPID > 0 && inst.DriverPID > 0 {
 			inst.Status = StatusRunning
-		} else if inst.HostAgentPID == 0 && inst.QemuPID == 0 {
+		} else if inst.HostAgentPID == 0 && inst.DriverPID == 0 {
 			inst.Status = StatusStopped
-		} else if inst.HostAgentPID > 0 && inst.QemuPID == 0 {
-			inst.Errors = append(inst.Errors, errors.New("host agent is running but qemu is not"))
+		} else if inst.HostAgentPID > 0 && inst.DriverPID == 0 {
+			inst.Errors = append(inst.Errors, errors.New("host agent is running but driver is not"))
 			inst.Status = StatusBroken
 		} else {
-			inst.Errors = append(inst.Errors, errors.New("qemu is running but host agent is not"))
+			inst.Errors = append(inst.Errors, fmt.Errorf("%s driver is running but host agent is not", inst.VMType))
 			inst.Status = StatusBroken
 		}
 	}
